@@ -1,3 +1,7 @@
+# -*- coding: utf-8 -*-
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
 import logging
 
 # Make sure that dictConfig is available
@@ -8,7 +12,7 @@ except ImportError:
     from rq.compat.dictconfig import dictConfig  # noqa
 
 
-def setup_loghandlers(verbose=False):
+def setup_loghandlers(level=None):
     if not logging._handlers:
         dictConfig({
             "version": 1,
@@ -24,7 +28,7 @@ def setup_loghandlers(verbose=False):
             "handlers": {
                 "console": {
                     "level": "DEBUG",
-                    #"class": "logging.StreamHandler",
+                    # "class": "logging.StreamHandler",
                     "class": "rq.utils.ColorizingStreamHandler",
                     "formatter": "console",
                     "exclude": ["%(asctime)s"],
@@ -33,6 +37,6 @@ def setup_loghandlers(verbose=False):
 
             "root": {
                 "handlers": ["console"],
-                "level": "DEBUG" if verbose else "INFO"
+                "level": level or "INFO",
             }
         })
