@@ -1,3 +1,7 @@
+# -*- coding: utf-8 -*-
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
 import uuid
 
 from .connections import resolve_connection
@@ -22,6 +26,7 @@ def compact(lst):
 
 @total_ordering
 class Queue(object):
+    job_class = Job
     DEFAULT_TIMEOUT = 180  # Default timeout seconds.
     redis_queue_namespace_prefix = 'rq:queue:'
     redis_queues_keys = 'rq:queues'
@@ -91,7 +96,7 @@ class Queue(object):
 
     def fetch_job(self, job_id):
         try:
-            return Job.fetch(job_id, connection=self.connection)
+            return self.job_class.fetch(job_id, connection=self.connection)
         except NoSuchJobError:
             self.remove(job_id)
 
@@ -127,7 +132,7 @@ class Queue(object):
 
     def remove(self, job_or_id):
         """Removes Job from queue, accepts either a Job instance or ID."""
-        job_id = job_or_id.id if isinstance(job_or_id, Job) else job_or_id
+        job_id = job_or_id.id if isinstance(job_or_id, self.job_class) else job_or_id
         return self.connection._lrem(self.key, 0, job_id)
 
     def compact(self):
@@ -141,15 +146,13 @@ class Queue(object):
             job_id = as_text(self.connection.lpop(COMPACT_QUEUE))
             if job_id is None:
                 break
-            if Job.exists(job_id, self.connection):
+            if self.job_class.exists(job_id, self.connection):
                 self.connection.rpush(self.key, job_id)
 
-
-    def push_job_id(self, job_id):  # noqa
+    def push_job_id(self, job_id):
         """Pushes a job ID on the corresponding Redis queue."""
         self.connection.rpush(self.key, job_id)
 
-
     def enqueue_call(self, func, args=None, kwargs=None, timeout=None,
                      result_ttl=None, description=None, depends_on=None):
         """Creates a job to represent the delayed function call and enqueues
@@ -162,7 +165,7 @@ class Queue(object):
         timeout = timeout or self._default_timeout
 
         # TODO: job with dependency shouldn't have "queued" as status
-        job = Job.create(func, args, kwargs, connection=self.connection,
+        job = self.job_class.create(func, args, kwargs, connection=self.connection,
                          result_ttl=result_ttl, status=Status.QUEUED,
                          description=description, depends_on=depends_on, timeout=timeout)
 
@@ -209,10 +212,10 @@ class Queue(object):
         description = kwargs.pop('description', None)
         result_ttl = kwargs.pop('result_ttl', None)
         depends_on = kwargs.pop('depends_on', None)
-        
+
         if 'args' in kwargs or 'kwargs' in kwargs:
             assert args == (), 'Extra positional arguments cannot be used when using explicit args and kwargs.'  # noqa
-            args = kwargs.pop('args', None)            
+            args = kwargs.pop('args', None)
             kwargs = kwargs.pop('kwargs', None)
 
         return self.enqueue_call(func=f, args=args, kwargs=kwargs,
@@ -252,7 +255,7 @@ class Queue(object):
             job_id = as_text(self.connection.spop(job.dependents_key))
             if job_id is None:
                 break
-            dependent = Job.fetch(job_id, connection=self.connection)
+            dependent = self.job_class.fetch(job_id, connection=self.connection)
             self.enqueue_job(dependent)
 
     def pop_job_id(self):
@@ -292,13 +295,13 @@ class Queue(object):
     def dequeue(self):
         """Dequeues the front-most job from this queue.
 
-        Returns a Job instance, which can be executed or inspected.
+        Returns a job_class instance, which can be executed or inspected.
         """
         job_id = self.pop_job_id()
         if job_id is None:
             return None
         try:
-            job = Job.fetch(job_id, connection=self.connection)
+            job = self.job_class.fetch(job_id, connection=self.connection)
         except NoSuchJobError as e:
             # Silently pass on jobs that don't exist (anymore),
             # and continue by reinvoking itself recursively
@@ -313,7 +316,7 @@ class Queue(object):
 
     @classmethod
     def dequeue_any(cls, queues, timeout, connection=None):
-        """Class method returning the Job instance at the front of the given
+        """Class method returning the job_class instance at the front of the given
         set of Queues, where the order of the queues is important.
 
         When all of the Queues are empty, depending on the `timeout` argument,
@@ -330,7 +333,7 @@ class Queue(object):
         queue_key, job_id = map(as_text, result)
         queue = cls.from_queue_key(queue_key, connection=connection)
         try:
-            job = Job.fetch(job_id, connection=connection)
+            job = cls.job_class.fetch(job_id, connection=connection)
         except NoSuchJobError:
             # Silently pass on jobs that don't exist (anymore),
             # and continue by reinvoking the same function recursively
@@ -343,7 +346,6 @@ class Queue(object):
             raise e
         return job, queue
 
-
     # Total ordering defition (the rest of the required Python methods are
     # auto-generated by the @total_ordering decorator)
     def __eq__(self, other):  # noqa
@@ -385,7 +387,7 @@ class FailedQueue(Queue):
     def requeue(self, job_id):
         """Requeues the job with the given job ID."""
         try:
-            job = Job.fetch(job_id, connection=self.connection)
+            job = self.job_class.fetch(job_id, connection=self.connection)
         except NoSuchJobError:
             # Silently ignore/remove this job and return (i.e. do nothing)
             self.remove(job_id)
