@@ -1,26 +1,33 @@
-import sys
-import os
+# -*- coding: utf-8 -*-
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
 import errno
+import logging
+import os
 import random
+import signal
+import socket
+import sys
 import time
+import traceback
+
+from rq.compat import as_text, text_type
+
+from .connections import get_current_connection
+from .exceptions import DequeueTimeout, NoQueueError
+from .job import Job, Status
+from .logutils import setup_loghandlers
+from .queue import get_failed_queue, Queue
+from .timeouts import UnixSignalDeathPenalty
+from .utils import make_colorizer, utcformat, utcnow
+from .version import VERSION
+
 try:
     from procname import setprocname
 except ImportError:
     def setprocname(*args, **kwargs):  # noqa
         pass
-import socket
-import signal
-import traceback
-import logging
-from .queue import Queue, get_failed_queue
-from .connections import get_current_connection
-from .job import Job, Status
-from .utils import make_colorizer, utcnow, utcformat
-from .logutils import setup_loghandlers
-from .exceptions import NoQueueError, DequeueTimeout
-from .timeouts import UnixSignalDeathPenalty
-from .version import VERSION
-from rq.compat import text_type, as_text
 
 green = make_colorizer('darkgreen')
 yellow = make_colorizer('darkyellow')
@@ -60,7 +67,8 @@ class Worker(object):
     redis_worker_namespace_prefix = 'rq:worker:'
     redis_workers_keys = 'rq:workers'
     death_penalty_class = UnixSignalDeathPenalty
-
+    queue_class = Queue
+    job_class = Job
 
     @classmethod
     def all(cls, connection=None):
@@ -95,7 +103,7 @@ class Worker(object):
         worker._state = connection.hget(worker.key, 'state') or '?'
         worker._job_id = connection.hget(worker.key, 'current_job') or None
         if queues:
-            worker.queues = [Queue(queue, connection=connection)
+            worker.queues = [self.queue_class(queue, connection=connection)
                              for queue in queues.split(',')]
         return worker
 
@@ -105,7 +113,7 @@ class Worker(object):
         if connection is None:
             connection = get_current_connection()
         self.connection = connection
-        if isinstance(queues, Queue):
+        if isinstance(queues, self.queue_class):
             queues = [queues]
         self._name = name
         self.queues = queues
@@ -133,13 +141,12 @@ class Worker(object):
         if exc_handler is not None:
             self.push_exc_handler(exc_handler)
 
-
-    def validate_queues(self):  # noqa
+    def validate_queues(self):
         """Sanity check for the given queues."""
         if not iterable(self.queues):
             raise ValueError('Argument queues not iterable.')
         for queue in self.queues:
-            if not isinstance(queue, Queue):
+            if not isinstance(queue, self.queue_class):
                 raise NoQueueError('Give each worker at least one Queue.')
 
     def queue_names(self):
@@ -150,8 +157,7 @@ class Worker(object):
         """Returns the Redis keys representing this worker's queues."""
         return map(lambda q: q.key, self.queues)
 
-
-    @property  # noqa
+    @property
     def name(self):
         """Returns the name of the worker, under which it is registered to the
         monitoring system.
@@ -194,8 +200,7 @@ class Worker(object):
         """
         setprocname('rq: %s' % (message,))
 
-
-    def register_birth(self):  # noqa
+    def register_birth(self):
         """Registers its own birth."""
         self.log.debug('Registering birth of worker %s' % (self.name,))
         if self.connection.exists(self.key) and \
@@ -266,7 +271,7 @@ class Worker(object):
         if job_id is None:
             return None
 
-        return Job.fetch(job_id, self.connection)
+        return self.job_class.fetch(job_id, self.connection)
 
     @property
     def stopped(self):
@@ -319,8 +324,7 @@ class Worker(object):
         signal.signal(signal.SIGINT, request_stop)
         signal.signal(signal.SIGTERM, request_stop)
 
-
-    def work(self, burst=False):  # noqa
+    def work(self, burst=False):
         """Starts the work loop.
 
         Pops and performs all jobs on the current list of queues.  When all
@@ -377,7 +381,7 @@ class Worker(object):
             self.heartbeat()
 
             try:
-                result = Queue.dequeue_any(self.queues, timeout,
+                result = self.queue_class.dequeue_any(self.queues, timeout,
                                            connection=self.connection)
                 if result is not None:
                     job, queue = result
@@ -471,7 +475,7 @@ class Worker(object):
 
         with self.connection._pipeline() as pipeline:
             try:
-                with self.death_penalty_class(job.timeout or Queue.DEFAULT_TIMEOUT):
+                with self.death_penalty_class(job.timeout or self.queue_class.DEFAULT_TIMEOUT):
                     rv = job.perform()
 
                 # Pickle the result in the same try-except block since we need to
